from setuptools import setup, find_packages

setup(
    name='pypract',
    version='0.1.0',
    description='A collection of practical codes for learning',
    packages=find_packages(),  
    install_requires=[],  
)
